@@ -10,7 +10,7 @@ class Order(WorkflowableEntityType):
     split_into = SubjectRelation('WorkOrder', cardinality='*1', composite='subject')
 
     # computed attributes
-    budget = Float(description=_('computed attribute'))
+    budget = Float(description=_('computed attribute'), required=True, default=0)
     progress_done = Float(description=_('computed attribute'))
     progress_todo = Float(description=_('computed attribute'))
 
